Ipv4UnicastSourceAndMulticastDestination

Struct Ipv4UnicastSourceAndMulticastDestination 

pub struct Ipv4UnicastSourceAndMulticastDestination {
    pub unicast_source: Ipv4Address,
    pub multicast_destination: Ipv4Address,
}
The source and destination address of an IPv4 multicast route.

This address tuple uniquely identifies an IPv4 multicast route.

Fields

unicast_source: Ipv4Address

A unicast source address found in a multicast packet.

multicast_destination: Ipv4Address

A multicast destination address found in a multicast packet.